@@ -1,4 +1,4 @@
-# Copyright 2015-2016  Lars Wirzenius
+# Copyright 2015-2017  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -223,21 +223,26 @@ class GAClient(object):
                 client_name=self._client_name,
                 gen_id=gen_number)
 
-        chunks_in_removed = self.get_generation_chunk_ids(gen_number)
-        chunks_remaining = self._get_chunk_ids_used_by_generations(remaining)
-        unused_chunks = set(chunks_in_removed).difference(chunks_remaining)
+        import cliapp
+        dumper = cliapp.MemoryProfileDumper({
+            'dump-memory-profile': True,
+            'memory-dump-interval': 0,
+        })
+        self._dumper = dumper
+
+        chunks_to_remove = set(self._generate_generation_chunk_ids(gen_number))
+        dumper.dump_memory_profile('after getting chunks in removed gen')
+
+        for chunk_id in self._generate_chunk_ids_in_generations(remaining):
+            if chunk_id in chunks_to_remove:
+                chunks_to_remove.remove(chunk_id)
+                if len(chunks_to_remove) == 0:
+                    break
+        dumper.dump_memory_profile('after computing chunk uniq to removed gen')
 
         self._generations.set_generations(remaining)
 
-        return list(unused_chunks)
-
-    def _get_chunk_ids_used_by_generations(self, generations):
-        chunk_ids = set()
-        for generation in generations:
-            gen_number = generation.get_number()
-            chunk_ids = chunk_ids.union(
-                set(self.get_generation_chunk_ids(gen_number)))
-        return chunk_ids
+        return list(chunks_to_remove)
 
     def get_generation_key(self, gen_number, key):
         self._load_data()
@@ -374,15 +379,33 @@ class GAClient(object):
                 filename=filename)
 
     def get_generation_chunk_ids(self, gen_number):
+        return list(self._generate_generation_chunk_ids(gen_number))
+
+    def _generate_generation_chunk_ids(self, gen_number):
+        if hasattr(self, '_dumper'):
+            dump = self._dumper.dump_memory_profile
+        else:
+            def dump(msg):
+                return None
+
         self._load_data()
+
         generation = self._lookup_generation_by_gen_number(gen_number)
+
         metadata = generation.get_file_metadata()
-        sets = [
-            set(metadata.get_file_chunk_ids(filename))
-            for filename in metadata
-        ]
-        union = set().union(*sets)
-        return list(union)
+        dump('after getting file metadata for generation')
+
+        for filename in metadata:
+            chunk_ids = metadata.get_file_chunk_ids(filename)
+            for chunk_id in chunk_ids:
+                yield chunk_id
+        dump('after yielding all chunk ids')
+
+    def _generate_chunk_ids_in_generations(self, generations):
+        for generation in generations:
+            gen_number = generation.get_number()
+            for chunk_id in self._generate_generation_chunk_ids(gen_number):
+                yield chunk_id
 
     def get_file_children(self, gen_number, filename):
         self._load_data()
