@@ -1,4 +1,4 @@
-# Copyright 2016  Lars Wirzenius
+# Copyright 2016-2017  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,10 @@ class CowLeaf(object):
     def insert(self, key, value):
         self._dict[key] = value
 
+    def remove(self, key):
+        if key in self._dict:
+            del self._dict[key]
+
     def as_dict(self):
         return copy.deepcopy(self._dict)
 
