@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2015  Lars Wirzenius
+# Copyright (C) 2010-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -259,7 +259,7 @@ class FsckPlugin(obnamlib.ObnamPlugin):
 
         self.app.settings.string_list(
             ['fsck-ignore-client'],
-            'do not check repository data for cient NAME',
+            'do not check repository data for client NAME',
             metavar='NAME',
             group=group)
 
