@@ -1,4 +1,5 @@
 # Copyright (C) 2009-2016  Lars Wirzenius
+# Copyright (C) 2017  SanskritFritz
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -314,9 +315,6 @@ class ShowPlugin(obnamlib.ObnamPlugin):
         enc_filename = enc_filename.replace(" ", "%20")
         enc_filename = enc_filename.replace("\t", "%09")
 
-        if filename == "/":
-            return
-
         self.app.output.write(
             "%s%s\t%d\t%#x\n" %
             (mode_str, enc_filename, size, mtime_sec))
